@@ -8,7 +8,7 @@ use Moo;
 
 use File::ShareDir qw( dist_file );
 use Path::Tiny 0.018 qw( cwd path );
-use Text::Template;
+use Text::Template 1.48;
 use Text::Wrap    qw( wrap $columns );
 use Types::Common qw( InstanceOf Maybe NonEmptyStr NonEmptySimpleStr PositiveInt );
 
@@ -16,7 +16,7 @@ use experimental qw( lexical_subs signatures );
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.2.0';
+our $VERSION = 'v0.3.0';
 
 
 has name => (
@@ -40,6 +40,15 @@ has entity => (
 );
 
 
+has Entity => (
+    is      => 'lazy',
+    isa     => NonEmptySimpleStr,
+    builder => sub($self) {
+        return ucfirst( $self->entity );
+    },
+);
+
+
 has policy => (
     is      => 'ro',
     default => 'Contributor_Covenant_1.4',
@@ -80,12 +89,18 @@ has text => (
     is      => 'lazy',
     isa     => NonEmptyStr,
     builder => sub($self) {
+        state $c = 1;
+        my $pkg = __PACKAGE__ . "::Run_" . $c++;
         my $raw = $self->_template->fill_in(
-            HASH => {
+            PACKAGE => $pkg,
+            STRICT  => 1,
+            BROKEN  => sub(%args) { die $args{error} },
+            HASH    => {
                 name    => $self->name,
                 contact => $self->contact,
                 entity  => $self->entity,
-            }
+                Entity  => $self->Entity,
+            },
         );
 
         $columns = $self->text_columns;
@@ -130,7 +145,7 @@ Software::Policy::CodeOfConduct - generate a Code of Conduct policy
 
 =head1 VERSION
 
-version v0.2.0
+version v0.3.0
 
 =head1 SYNOPSIS
 
@@ -167,6 +182,10 @@ It is required.
 
 A generating name for the project. It defaults to "project" but the original templates used "community".
 
+=head2 Entity
+
+A sentence-case (ucfirst) form of L</entity>.
+
 =head2 policy
 
 This is the policy filename. It defaults to "Contributor_Covenant_1.4" which is based on
@@ -238,7 +257,7 @@ patch to an existing test-file that illustrates the bug or desired
 feature.
 
 If the bug you are reporting has security implications which make it inappropriate to send to a public issue tracker,
-then see F<SECURITY.md> for instructions how to report security vulnerabilities
+then see F<SECURITY.md> for instructions how to report security vulnerabilities.
 
 =head1 AUTHOR
 
